==> webkit2gtk_2.46.1.orig.tar.xz: webkitgtk-2.46.1/Source/bmalloc/bmalloc/CompactAllocationMode.h <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "BAssert.h"
#include "BInline.h"

#if BUSE(LIBPAS)
#include "pas_allocation_mode.h"
#endif

namespace bmalloc {

enum class CompactAllocationMode {
    Compact,
    NonCompact
};

static constexpr unsigned numAllocationModes = 2;

#if BUSE(LIBPAS)

BINLINE constexpr pas_allocation_mode asPasAllocationMode(CompactAllocationMode mode)
{
    switch (mode) {
    case CompactAllocationMode::Compact:
        return pas_compact_allocation_mode;
    case CompactAllocationMode::NonCompact:
        return pas_non_compact_allocation_mode;
    }
    RELEASE_BASSERT_NOT_REACHED();
}

#endif

} // namespace bmalloc

==> webkit2gtk_2.48.1.orig.tar.xz: webkitgtk-2.48.1/Source/bmalloc/bmalloc/CompactAllocationMode.h <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "BAssert.h"
#include "BInline.h"

#if BUSE(LIBPAS)
BALLOW_UNSAFE_BUFFER_USAGE_BEGIN
#include "pas_allocation_mode.h"
BALLOW_UNSAFE_BUFFER_USAGE_END
#endif

namespace bmalloc {

enum class CompactAllocationMode {
    NonCompact,
    Compact
};

static constexpr unsigned numAllocationModes = 2;

#if BUSE(LIBPAS)

BINLINE constexpr pas_allocation_mode asPasAllocationMode(CompactAllocationMode mode)
{
    switch (mode) {
    case CompactAllocationMode::NonCompact:
        return pas_non_compact_allocation_mode;
    case CompactAllocationMode::Compact:
        return pas_maybe_compact_allocation_mode;
    }
    RELEASE_BASSERT_NOT_REACHED();
}

#endif

} // namespace bmalloc
